@@ -1,7 +1,7 @@
 
 from .hello import hello
 
-from .data.datasets import GenernalDataset, GenernalDataTrainingArguments
+# from .data.datasets import GenernalDataset, GenernalDataTrainingArguments
 
 from .data import (
     genernal_convert_examples_to_features,
@@ -10,6 +10,8 @@ from .data import (
     SmpRankProcessor,
     genernal_tasks_num_labels,
     genernal_compute_metrics,
+    GenernalDataset,
+    GenernalDataTrainingArguments,
 )
 
 from .textclassification import TextClassificationModel
